@@ -588,7 +588,6 @@ class OculScholarsPortalPreservation(models.Model):
         return None, False
 
     @staticmethod
-    @transaction.atomic
     def import_data(url, bucket="", s3client=None):
         # download the data file from S3 bucket
         with tempfile.TemporaryDirectory() as tmp:
@@ -623,9 +622,10 @@ class OculScholarsPortalPreservation(models.Model):
         :return: None
         """
 
-        publisher = 'Undefined' if 'publisher' not in output \
-                                   or output['publisher'] is None \
-            else publisher = output['publisher']
+        if 'publisher' not in output or output['publisher'] is None:
+            publisher = 'Default'
+        else:
+            publisher = output['publisher']
 
         publisher, created = \
             Publisher.objects.get_or_create(name=publisher)
